summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-06-10 07:14:50 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-06-10 07:14:50 -0500
commit32751e6a20d8f7837471f83c5003a7859c1260ef (patch)
tree2d13a0671fbcf139d3738dacc3856d70dd9943bb
parentd522ff063f41d33d7f4797ccfcedb6ba3220459b (diff)
downloadlibpng-32751e6a20d8f7837471f83c5003a7859c1260ef.tar.gz
[libpng15] Removed some unused WEIGHTED_FILTER macros from png.h and pngstruct.h
-rw-r--r--png.h18
-rw-r--r--pngstruct.h10
2 files changed, 5 insertions, 23 deletions
diff --git a/pngstruct.h b/pngstruct.h
index 887ac0b15..e5e1af69c 100644
--- a/pngstruct.h
+++ b/pngstruct.h
@@ -236,16 +236,6 @@ struct png_struct_def
png_uint_16p hist; /* histogram */
#endif
-#ifdef PNG_WRITE_WEIGHTED_FILTER_SUPPORTED
- png_byte heuristic_method; /* heuristic for row filter selection */
- png_byte num_prev_filters; /* number of weights for previous rows */
- png_bytep prev_filters; /* filter type(s) of previous row(s) */
- png_uint_16p filter_weights; /* weight(s) for previous line(s) */
- png_uint_16p inv_filter_weights; /* 1/weight(s) for previous line(s) */
- png_uint_16p filter_costs; /* relative filter calculation cost */
- png_uint_16p inv_filter_costs; /* 1/relative filter calculation cost */
-#endif
-
#ifdef PNG_TIME_RFC1123_SUPPORTED
/* This is going to be unused in libpng16 and removed from libpng17 */
char time_buffer[29]; /* String to hold RFC 1123 time text */
diff --git a/png.h b/png.h
index ec7c31ef3..f42f13adb 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.23beta02, June 1, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.23beta02, June 1, 2015: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -241,7 +241,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.23beta02, June 1, 2015, are
* Copyright (c) 2004, 2006-2015 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -353,7 +353,7 @@
* Y2K compliance in libpng:
* =========================
*
- * June 1, 2015
+ * June 10, 2015
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -422,7 +422,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.5.23beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.23beta02 - June 1, 2015\n"
+ " libpng version 1.5.23beta02 - June 10, 2015\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -1682,14 +1682,6 @@ PNG_FIXED_EXPORT(209, void, png_set_filter_heuristics_fixed,
filter_weights, png_const_fixed_point_p filter_costs))
#endif /* PNG_WRITE_WEIGHTED_FILTER_SUPPORTED */
-/* Heuristic used for row filter selection. These defines should NOT be
- * changed.
- */
-#define PNG_FILTER_HEURISTIC_DEFAULT 0 /* Currently "UNWEIGHTED" */
-#define PNG_FILTER_HEURISTIC_UNWEIGHTED 1 /* Used by libpng < 0.95 */
-#define PNG_FILTER_HEURISTIC_WEIGHTED 2 /* Experimental feature */
-#define PNG_FILTER_HEURISTIC_LAST 3 /* Not a valid value */
-
#ifdef PNG_WRITE_SUPPORTED
/* Set the library compression level. Currently, valid values range from
* 0 - 9, corresponding directly to the zlib compression levels 0 - 9
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.23beta02, June 1, 2015
+ * libpng version 1.5.23beta02, June 10, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.23beta02, June 1, 2015: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.23beta02, June 10, 2015: Glenn
* See also "Contributing Authors", below.
*
@@ -241,7 +241,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.23beta02, June 1, 2015, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.23beta02, June 10, 2015, are
* Copyright (c) 2004, 2006-2015 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5